@@ -1,12 +1,14 @@
 # constructor.r ##########################################################################################################
 # FUNCTION:         DESCRIPTION:
-#  .check.par		Checks, whether the parameter are correctly specified, i.e., ascending ordered from lowest to the highest hierarchical level. (Internal function)
-#  .check			Checks, whether the parameters of two subsequent nodes are correctly specified. (Internal function)
-#  hac.full			Constructs 'hac' objects for fully nested Archimedean Copulae.
-#  hac				Constructs 'hac' objects for arbitrary nested Archimedean Copulae.
-#  print.hac     	Prints 'hac' objects.
+#  .check.par		    Checks, whether the parameter are correctly specified, i.e., ascending ordered from lowest to the highest hierarchical level. (Internal function)
+#  .check			      Checks, whether the parameters of two subsequent nodes are correctly specified. (Internal function)
+#  hac.full			    Constructs 'hac' objects for fully nested Archimedean Copulae.
+#  hac				      Constructs 'hac' objects for arbitrary nested Archimedean Copulae.
+#  print.hac     	  Prints 'hac' objects.
 #  hac2nacopula     Converts an 'hac' object into a 'nacopula' object.
+#  .tree2nacList    Converts a 'tree' structure into a 'nacList'. (Internal function) 
 #  nacopula2hac     Converts a 'nacopula' object into an 'hac' object.
+#  .nacopula2tree   Converts a 'nacopula' object into a 'tree' structure. (Internal function)
 ##########################################################################################################################
 
 .check.par = function(x){
@@ -124,4 +126,54 @@ hac2nacopula = function(x){
            res = list(tree[[n]], NULL, lapply(tree[which(!s)], FUN = .tree2nacList, names = names, numbers = numbers))
          }
      res
+}
+
+#------------------------------------------------------------------------------------------------------------------------
+
+nacopula2hac = function(outer_nacopula){
+  if(class(outer_nacopula) != "outer_nacopula"){stop("An outer_nacopula object is required.")}
+	.family = character(1)
+	n.childs = length(outer_nacopula@childCops)
+	if(outer_nacopula@copula@name == "Gumbel"){
+	   .family = if(n.childs > 0){1}else{2}
+	}else
+	if(outer_nacopula@copula@name == "Clayton"){
+		.family = if(n.childs > 0){3}else{4}
+  }else
+	if(outer_nacopula@copula@name == "Frank"){
+		.family = if(n.childs > 0){5}else{6}
+	}else
+	if(outer_nacopula@copula@name == "Joe"){
+		.family = if(n.childs > 0){7}else{8}
+	}else
+	if(outer_nacopula@copula@name == "AMH"){
+		.family = if(n.childs > 0){9}else{10}
+	}
+	hac(type = .family, tree = .nacopula2tree(outer_nacopula))
+}
+
+#------------------------------------------------------------------------------------------------------------------------
+
+.nacopula2tree = function(outer_nacopula){
+	 
+   comps = outer_nacopula@comp
+   n.comps = length(comps)
+   n.childs = length(outer_nacopula@childCops)
+	 
+     if(n.childs > 0){
+         if(n.comps > 0){	
+           res = vector("list", n.comps + n.childs + 1)
+           for(j in 1:n.comps){res[[j]] = paste("X", comps[j], sep = "")}
+           for(j in (n.comps + 1):(n.comps + n.childs)){res[[j]] = .nacopula2tree(outer_nacopula@childCops[[j - n.comps]])}
+           res[[n.comps + n.childs + 1]] = outer_nacopula@copula@theta
+         }else{
+           res = vector("list", n.childs + 1)
+           for(j in 1:n.childs){res[[j]] = .nacopula2tree(outer_nacopula@childCops[[j]])}
+           res[[n.childs + 1]] = outer_nacopula@copula@theta
+         }}else{
+           res = vector("list", n.comps + 1)
+           for(j in 1:n.comps){res[[j]] = paste("X", comps[j], sep = "")}
+           res[[n.comps + 1]] = outer_nacopula@copula@theta
+         }
+     res
 }
\ No newline at end of file
